================
Management Tools
================

:Version: 0.1.1
:Status: Production/Stable
:Author: José Antonio Perdiguero López

A set of tools to measure and improve efficiency in team management tasks.
